@@ -43,11 +43,12 @@ namespace heif {
   class StreamReader
   {
   public:
-    virtual ~StreamReader() { }
+    virtual ~StreamReader() = default;
 
     virtual int64_t get_position() const = 0;
 
-    enum grow_status {
+    enum grow_status
+    {
       size_reached,   // requested size has been reached
       timeout,        // size has not been reached yet, but it may still grow further
       size_beyond_eof // size has not been reached and never will. The file has grown to its full size
@@ -57,11 +58,12 @@ namespace heif {
     virtual grow_status wait_for_file_size(int64_t target_size) = 0;
 
     // returns 'false' when we read out of the available file size
-    virtual bool    read(void* data, size_t size) = 0;
+    virtual bool read(void* data, size_t size) = 0;
 
-    virtual bool    seek(int64_t position) = 0;
+    virtual bool seek(int64_t position) = 0;
 
-    bool seek_cur(int64_t position_offset) {
+    bool seek_cur(int64_t position_offset)
+    {
       return seek(get_position() + position_offset);
     }
   };
@@ -76,9 +78,9 @@ namespace heif {
 
     grow_status wait_for_file_size(int64_t target_size) override;
 
-    bool    read(void* data, size_t size) override;
+    bool read(void* data, size_t size) override;
 
-    bool    seek(int64_t position) override;
+    bool seek(int64_t position) override;
 
   private:
     std::unique_ptr<std::istream> m_istr;
@@ -90,15 +92,16 @@ namespace heif {
   {
   public:
     StreamReader_memory(const uint8_t* data, int64_t size, bool copy);
-    ~StreamReader_memory();
+
+    ~StreamReader_memory() override;
 
     int64_t get_position() const override;
 
     grow_status wait_for_file_size(int64_t target_size) override;
 
-    bool    read(void* data, size_t size) override;
+    bool read(void* data, size_t size) override;
 
-    bool    seek(int64_t position) override;
+    bool seek(int64_t position) override;
 
   private:
     const uint8_t* m_data;
@@ -115,12 +118,16 @@ namespace heif {
   public:
     StreamReader_CApi(const heif_reader* func_table, void* userdata);
 
-    int64_t get_position() const override { return m_func_table->get_position(m_userdata); }
+    int64_t get_position() const override
+    { return m_func_table->get_position(m_userdata); }
 
     StreamReader::grow_status wait_for_file_size(int64_t target_size) override;
 
-    bool    read(void* data, size_t size) override { return !m_func_table->read(data,size,m_userdata); }
-    bool    seek(int64_t position) override { return !m_func_table->seek(position,m_userdata); }
+    bool read(void* data, size_t size) override
+    { return !m_func_table->read(data, size, m_userdata); }
+
+    bool seek(int64_t position) override
+    { return !m_func_table->seek(position, m_userdata); }
 
   private:
     const heif_reader* m_func_table;
@@ -143,15 +150,21 @@ namespace heif {
     StreamReader::grow_status wait_until_range_is_available();
 
     uint8_t read8();
+
     uint16_t read16();
+
     uint32_t read32();
+
     std::string read_string();
 
+    bool read(uint8_t* data, int64_t n);
+
     bool prepare_read(int64_t nBytes);
 
     StreamReader::grow_status wait_for_available_bytes(int64_t nBytes);
 
-    void skip_to_end_of_file() {
+    void skip_to_end_of_file()
+    {
       // we do not actually move the file position here (because the stream may still be incomplete),
       // but we set all m_remaining to zero
       m_remaining = 0;
@@ -161,8 +174,9 @@ namespace heif {
       }
     }
 
-    void skip_to_end_of_box() {
-      if (m_remaining>0) {
+    void skip_to_end_of_box()
+    {
+      if (m_remaining > 0) {
         if (m_parent_range) {
           // also advance position in parent range
           m_parent_range->skip_without_advancing_file_pos(m_remaining);
@@ -173,7 +187,8 @@ namespace heif {
       }
     }
 
-    void set_eof_while_reading() {
+    void set_eof_while_reading()
+    {
       m_remaining = 0;
 
       if (m_parent_range) {
@@ -183,15 +198,18 @@ namespace heif {
       m_error = true;
     }
 
-    bool eof() const {
+    bool eof() const
+    {
       return m_remaining == 0;
     }
 
-    bool error() const {
+    bool error() const
+    {
       return m_error;
     }
 
-    Error get_error() const {
+    Error get_error() const
+    {
       if (m_error) {
         return Error(heif_error_Invalid_input,
                      heif_suberror_End_of_data);
@@ -201,13 +219,16 @@ namespace heif {
       }
     }
 
-    std::shared_ptr<StreamReader> get_istream() { return m_istr; }
+    std::shared_ptr<StreamReader> get_istream()
+    { return m_istr; }
 
-    int get_nesting_level() const { return m_nesting_level; }
+    int get_nesting_level() const
+    { return m_nesting_level; }
 
-    int64_t get_remaining_bytes() const { return m_remaining; }
+    int64_t get_remaining_bytes() const
+    { return m_remaining; }
 
-private:
+  private:
     std::shared_ptr<StreamReader> m_istr;
     BitstreamRange* m_parent_range = nullptr;
     int m_nesting_level = 0;
@@ -220,23 +241,37 @@ private:
   };
 
 
-
   class BitReader
   {
   public:
     BitReader(const uint8_t* buffer, int len);
 
     int get_bits(int n);
+
     int get_bits_fast(int n);
+
     int peek_bits(int n);
+
+    void skip_bytes(int nBytes);
+
     void skip_bits(int n);
+
     void skip_bits_fast(int n);
+
     void skip_to_byte_boundary();
+
     bool get_uvlc(int* value);
+
     bool get_svlc(int* value);
 
-    int get_current_byte_index() const {
-      return data_length - bytes_remaining - nextbits_cnt/8;
+    int get_current_byte_index() const
+    {
+      return data_length - bytes_remaining - nextbits_cnt / 8;
+    }
+
+    int64_t get_bits_remaining() const
+    {
+      return ((int64_t) bytes_remaining) * 8 + nextbits_cnt;
     }
 
   private:
@@ -251,30 +286,43 @@ private:
   };
 
 
-
   class StreamWriter
   {
   public:
     void write8(uint8_t);
+
     void write16(uint16_t);
+
     void write32(uint32_t);
+
     void write64(uint64_t);
+
     void write(int size, uint64_t value);
+
     void write(const std::string&);
+
     void write(const std::vector<uint8_t>&);
+
     void write(const StreamWriter&);
 
     void skip(int n);
 
     void insert(int nBytes);
 
-    size_t data_size() const { return m_data.size(); }
+    size_t data_size() const
+    { return m_data.size(); }
 
-    size_t get_position() const { return m_position; }
-    void set_position(size_t pos) { m_position=pos; }
-    void set_position_to_end() { m_position=m_data.size(); }
+    size_t get_position() const
+    { return m_position; }
 
-    const std::vector<uint8_t> get_data() const { return m_data; }
+    void set_position(size_t pos)
+    { m_position = pos; }
+
+    void set_position_to_end()
+    { m_position = m_data.size(); }
+
+    const std::vector<uint8_t> get_data() const
+    { return m_data; }
 
   private:
     std::vector<uint8_t> m_data;
