@@ -81,19 +81,24 @@ uint32_t heif_get_version_number(void)
   return (LIBHEIF_NUMERIC_VERSION);
 }
 
+static uint8_t bcd2dec(uint8_t v)
+{
+  return uint8_t((v>>4) * 10 + (v & 0x0F));
+}
+
 int heif_get_version_number_major(void)
 {
-  return ((LIBHEIF_NUMERIC_VERSION) >> 24) & 0xFF;
+  return bcd2dec(((LIBHEIF_NUMERIC_VERSION) >> 24) & 0xFF);
 }
 
 int heif_get_version_number_minor(void)
 {
-  return ((LIBHEIF_NUMERIC_VERSION) >> 16) & 0xFF;
+  return bcd2dec(((LIBHEIF_NUMERIC_VERSION) >> 16) & 0xFF);
 }
 
 int heif_get_version_number_maintenance(void)
 {
-  return ((LIBHEIF_NUMERIC_VERSION) >> 8) & 0xFF;
+  return bcd2dec(((LIBHEIF_NUMERIC_VERSION) >> 8) & 0xFF);
 }
 
 
@@ -201,6 +206,9 @@ heif_brand heif_fourcc_to_brand_enum(const char* fourcc)
   else if (strcmp(brand, "avis") == 0) {
     return heif_avis;
   }
+  else if (strcmp(brand, "vvic") == 0) {
+    return heif_vvic;
+  }
   else {
     return heif_unknown_brand;
   }
@@ -903,14 +911,14 @@ heif_decoding_options* heif_decoding_options_alloc()
 {
   auto options = new heif_decoding_options;
 
-  options->version = 3;
+  options->version = 4;
 
   options->ignore_transformations = false;
 
-  options->start_progress = NULL;
-  options->on_progress = NULL;
-  options->end_progress = NULL;
-  options->progress_user_data = NULL;
+  options->start_progress = nullptr;
+  options->on_progress = nullptr;
+  options->end_progress = nullptr;
+  options->progress_user_data = nullptr;
 
   // version 2
 
@@ -920,6 +928,10 @@ heif_decoding_options* heif_decoding_options_alloc()
 
   options->strict_decoding = false;
 
+  // version 4
+
+  options->decoder_id = nullptr;
+
   return options;
 }
 
@@ -996,6 +1008,111 @@ void heif_image_add_decoding_warning(struct heif_image* image,
 }
 
 
+int heif_image_has_content_light_level(const struct heif_image* image)
+{
+  return image->image->has_clli();
+}
+
+void heif_image_get_content_light_level(const struct heif_image* image, struct heif_content_light_level* out)
+{
+  if (out) {
+    *out = image->image->get_clli();
+  }
+}
+
+void heif_image_set_content_light_level(const struct heif_image* image, const struct heif_content_light_level* in)
+{
+  if (in==nullptr) {
+    return;
+  }
+
+  image->image->set_clli(*in);
+}
+
+
+int heif_image_has_mastering_display_colour_volume(const struct heif_image* image)
+{
+  return image->image->has_mdcv();
+}
+
+void heif_image_get_mastering_display_colour_volume(const struct heif_image* image, struct heif_mastering_display_colour_volume* out)
+{
+  *out = image->image->get_mdcv();
+}
+
+void heif_image_set_mastering_display_colour_volume(const struct heif_image* image, const struct heif_mastering_display_colour_volume* in)
+{
+  if (in==nullptr) {
+    return;
+  }
+
+  image->image->set_mdcv(*in);
+}
+
+float mdcv_coord_decode_x(uint16_t coord)
+{
+  // check for unspecified value
+  if (coord<5 || coord>37000) {
+    return 0.0f;
+  }
+
+  return (float)(coord * 0.00002);
+}
+
+float mdcv_coord_decode_y(uint16_t coord)
+{
+  // check for unspecified value
+  if (coord<5 || coord>42000) {
+    return 0.0f;
+  }
+
+  return (float)(coord * 0.00002);
+}
+
+struct heif_error heif_mastering_display_colour_volume_decode(const struct heif_mastering_display_colour_volume* in,
+                                                              struct heif_decoded_mastering_display_colour_volume* out)
+{
+  if (in==nullptr || out==nullptr) {
+    return error_null_parameter;
+  }
+
+  for (int c=0;c<3;c++) {
+    out->display_primaries_x[c] = mdcv_coord_decode_x(in->display_primaries_x[c]);
+    out->display_primaries_y[c] = mdcv_coord_decode_y(in->display_primaries_y[c]);
+  }
+
+  out->white_point_x = mdcv_coord_decode_x(in->white_point_x);
+  out->white_point_y = mdcv_coord_decode_y(in->white_point_y);
+
+  if (in->max_display_mastering_luminance < 50000 || in->max_display_mastering_luminance > 100000000) {
+    out->max_display_mastering_luminance = 0;
+  }
+  else {
+    out->max_display_mastering_luminance = in->max_display_mastering_luminance * 0.0001;
+  }
+
+  if (in->min_display_mastering_luminance < 1 || in->min_display_mastering_luminance > 50000) {
+    out->min_display_mastering_luminance = 0;
+  }
+  else {
+    out->min_display_mastering_luminance = in->min_display_mastering_luminance * 0.0001;
+  }
+
+  return error_Ok;
+}
+
+
+void heif_image_get_pixel_aspect_ratio(const struct heif_image* image, uint32_t* aspect_h, uint32_t* aspect_v)
+{
+  image->image->get_pixel_ratio(aspect_h, aspect_v);
+}
+
+void heif_image_set_pixel_aspect_ratio(struct heif_image* image, uint32_t aspect_h, uint32_t aspect_v)
+{
+  image->image->set_pixel_ratio(aspect_h, aspect_v);
+}
+
+
 void heif_image_release(const struct heif_image* img)
 {
   delete img;
@@ -1162,6 +1279,20 @@ int heif_image_is_premultiplied_alpha(struct heif_image* image)
 }
 
 
+struct heif_error heif_image_extend_padding_to_size(struct heif_image* image, int min_physical_width, int min_physical_height)
+{
+  bool mem_alloc_success = image->image->extend_padding_to_size(min_physical_width, min_physical_height);
+  if (!mem_alloc_success) {
+    return heif_error{heif_error_Memory_allocation_error,
+                      heif_suberror_Unspecified,
+                      "Cannot allocate image memory."};
+  }
+  else {
+    return heif_error{heif_error_Ok, heif_suberror_Unspecified, Error::kSuccess};
+  }
+}
+
+
 struct heif_error heif_image_scale_image(const struct heif_image* input,
                                          struct heif_image** output,
                                          int width, int height,
@@ -1615,7 +1746,7 @@ struct heif_error heif_register_decoder(heif_context* heif, const heif_decoder_p
   if (!decoder_plugin) {
     return error_null_parameter;
   }
-  else if (decoder_plugin->plugin_api_version > 2) {
+  else if (decoder_plugin->plugin_api_version > 3) {
     return error_unsupported_plugin_version;
   }
 
@@ -1629,7 +1760,7 @@ struct heif_error heif_register_decoder_plugin(const heif_decoder_plugin* decode
   if (!decoder_plugin) {
     return error_null_parameter;
   }
-  else if (decoder_plugin->plugin_api_version > 2) {
+  else if (decoder_plugin->plugin_api_version > 3) {
     return error_unsupported_plugin_version;
   }
 
@@ -1721,6 +1852,15 @@ int heif_context_get_encoder_descriptors(struct heif_context* ctx,
                                          const char* name,
                                          const struct heif_encoder_descriptor** out_encoder_descriptors,
                                          int count)
+{
+  return heif_get_encoder_descriptors(format, name, out_encoder_descriptors, count);
+}
+
+
+int heif_get_encoder_descriptors(enum heif_compression_format format,
+                                 const char* name,
+                                 const struct heif_encoder_descriptor** out_encoder_descriptors,
+                                 int count)
 {
   if (out_encoder_descriptors == nullptr || count <= 0) {
     return 0;
@@ -1750,6 +1890,71 @@ const char* heif_encoder_descriptor_get_id_name(const struct heif_encoder_descri
 }
 
 
+int heif_get_decoder_descriptors(enum heif_compression_format format_filter,
+                                 const struct heif_decoder_descriptor** out_decoders,
+                                 int count)
+{
+  struct decoder_with_priority {
+    const heif_decoder_plugin* plugin;
+    int priority;
+  };
+
+  std::vector<decoder_with_priority> plugins;
+  std::vector<heif_compression_format> formats;
+  if (format_filter == heif_compression_undefined) {
+    formats = { heif_compression_HEVC, heif_compression_AV1, heif_compression_VVC };
+  }
+  else {
+    formats.emplace_back(format_filter);
+  }
+
+  for (const auto* plugin : s_decoder_plugins) {
+    for (auto& format : formats) {
+      int priority = plugin->does_support_format(format);
+      if (priority) {
+        plugins.push_back({plugin, priority});
+        break;
+      }
+    }
+  }
+
+  if (out_decoders == nullptr) {
+    return (int)plugins.size();
+  }
+
+  std::sort(plugins.begin(), plugins.end(), [](const decoder_with_priority& a, const decoder_with_priority& b) {
+    return a.priority > b.priority;
+  });
+
+  int nDecodersReturned = std::min(count, (int)plugins.size());
+
+  for (int i=0;i<nDecodersReturned;i++) {
+    out_decoders[i] = (heif_decoder_descriptor*)(plugins[i].plugin);
+  }
+
+  return nDecodersReturned;
+}
+
+
+const char* heif_decoder_descriptor_get_name(const struct heif_decoder_descriptor* descriptor)
+{
+  auto decoder = (heif_decoder_plugin*)descriptor;
+  return decoder->get_plugin_name();
+}
+
+
+const char* heif_decoder_descriptor_get_id_name(const struct heif_decoder_descriptor* descriptor)
+{
+  auto decoder = (heif_decoder_plugin*)descriptor;
+  if (decoder->plugin_api_version < 3) {
+    return nullptr;
+  }
+  else {
+    return decoder->id_name;
+  }
+}
+
+
 enum heif_compression_format
 heif_encoder_descriptor_get_compression_format(const struct heif_encoder_descriptor* descriptor)
 {
@@ -1808,7 +2013,7 @@ struct heif_error heif_context_get_encoder(struct heif_context* context,
 
 int heif_have_decoder_for_format(enum heif_compression_format format)
 {
-  auto plugin = heif::get_decoder(format);
+  auto plugin = heif::get_decoder(format, nullptr);
   return plugin != nullptr;
 }
 
