@@ -21,12 +21,13 @@
 #ifndef LIBHEIF_HEIF_ENCODER_SVT_H
 #define LIBHEIF_HEIF_ENCODER_SVT_H
 
+#include "libheif/common_utils.h"
 
 const struct heif_encoder_plugin* get_encoder_plugin_svt();
 
 #if PLUGIN_SvtEnc
 extern "C" {
-__attribute__((unused)) LIBHEIF_API extern heif_plugin_info plugin_info;
+MAYBE_UNUSED LIBHEIF_API extern heif_plugin_info plugin_info;
 }
 #endif
 
