@@ -11,6 +11,7 @@ fi
 
 LIBSTDC_BASE=http://de.archive.ubuntu.com/ubuntu/pool/main/g/gcc-5
 EMSDK_DOWNLOAD=https://github.com/emscripten-core/emsdk.git
+EMSDK_VERSION=3.1.29
 
 CODENAME=$(/usr/bin/lsb_release --codename --short)
 if [ "$CODENAME" = "trusty" ] && [ ! -e "/usr/lib/x86_64-linux-gnu/libstdc++.so.6.0.21" ]; then
@@ -32,8 +33,10 @@ if [ ! -d emsdk ]; then
 fi
 
 cd emsdk
-echo "Updating SDK ..."
+echo "Updating SDK base to ${EMSDK_VERSION} ..."
+git checkout main
 git pull --verbose
+git checkout ${EMSDK_VERSION}
 
 echo "Installing SDK version ${VERSION} ..."
 ./emsdk install sdk-fastcomp-${VERSION}-64bit
